@@ -84,6 +84,10 @@ marg <- function(mod, var_interest, data = NULL,
                   at_var_interest = NULL,  at = NULL,
                   cofint = 0.95, ...){
 
+  # If mod$formula is a string, the error message is deeply uninformative
+  if(! "formula" %in% class(mod$formula))
+    stop("Estimate your model with a formula object, not a character string.")
+
   # Check arguments ---
   stopifnot(type %in% c('levels', 'effects'),
             is.numeric(cofint),
@@ -137,8 +141,11 @@ marg <- function(mod, var_interest, data = NULL,
         warning(sprintf("Not all values in 'at' are in the range of '%s'",
                         names(at)[i]))
     } else {
-      if(! at[[i]] %in% data[[names(at)[i]]])
-        stop(sprintf("'%s' is not a value in '%s'", at[[i]], names(at)[i]))
+      if(! all(at[[i]] %in% data[[names(at)[i]]]))
+        stop(sprintf("'%s' is not a value in '%s'",
+                     paste(at[[i]][! at[[i]] %in% data[[names(at)[i]]]],
+                           collapse = ", "),
+                     names(at)[i]))
     }
   }
 
